summaryrefslogtreecommitdiff
path: root/src/lib/player.h
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2021-09-15 23:36:21 +0200
committerCarl Hetherington <cth@carlh.net>2021-09-27 13:41:46 +0200
commit3799e91d126d243d41c44dcb0ca1bfa66b53a57e (patch)
tree74348b18d5ac0ef81bbebb27fe32862b22baa0b2 /src/lib/player.h
parent9bfa07293928c371d59db2091ba2b7e715ce5994 (diff)
Replace aligned bool with enum Alignment.
Diffstat (limited to 'src/lib/player.h')
-rw-r--r--src/lib/player.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/lib/player.h b/src/lib/player.h
index 767218379..b74aeeefd 100644
--- a/src/lib/player.h
+++ b/src/lib/player.h
@@ -34,6 +34,7 @@
#include "content_video.h"
#include "empty.h"
#include "film.h"
+#include "image.h"
#include "piece.h"
#include "player_text.h"
#include "position_image.h"
@@ -76,7 +77,7 @@ public:
class Player : public std::enable_shared_from_this<Player>
{
public:
- Player (std::shared_ptr<const Film>, bool aligned_subtitles);
+ Player (std::shared_ptr<const Film>, Image::Alignment subtitle_alignment);
Player (std::shared_ptr<const Film>, std::shared_ptr<const Playlist> playlist);
Player (Player const& Player) = delete;
@@ -233,8 +234,8 @@ private:
dcpomatic::DCPTime _playback_length;
- /** aligned flag for subtitle images that we create */
- bool _aligned_subtitles = true;
+ /** Alignment for subtitle images that we create */
+ Image::Alignment _subtitle_alignment = Image::Alignment::PADDED;
boost::signals2::scoped_connection _film_changed_connection;
boost::signals2::scoped_connection _playlist_change_connection;